@@ -21,8 +21,18 @@ $PERL = '/usr/bin/perl';
 #  Give the paths to latex and dvips on your system:
 #
 $LATEX = '/usr/bin/latex';	# LaTeX
+$PDFLATEX = '/usr/bin/pdflatex';	# pdfLaTeX
+$LUALATEX = '/usr/bin/lualatex';	# LuaLaTeX
+$DVILUALATEX = '/usr/bin/dvilualatex';	# dviLuaLaTeX
 $DVIPS = '/usr/bin/dvips';	# dvips
+$DVIPNG = '/usr/bin/dvipng';	# dvipng
+$PDFTOCAIRO = '/usr/bin/pdftocairo';	# pdf to svg converter
+$PS2PDF = '/usr/bin/ps2pdf';	# ps to pdf converter
+$PDFCROP = '/usr/bin/pdfcrop';	# pdfcrop
+$GS = '/usr/bin/gs';	# GhostScript
 
+$USE_PDFTEX = 1;	# use pdflatex unless -nouse_pdftex on command line
+$USE_DVIPNG = 1;
 
 #  give these too, to use the  -ldump  feature
 #
@@ -32,10 +42,12 @@ $INILATEX = "/usr/bin/initex \"&latex\"";	# initex+latex
 
 # These affect whether images are made on a white or gray background.
 # They are ignored when the document preamble contains similar commands.
-# Use these defaults for dark solid (anti-aliased) characters in text and math.
+# Default is white background.  Color should be specified as RGB hex
+# values using uppercase for A-F.  Grey background can be used for thicker
+# anti-aliased characters in text and math, at the cost of some fuzziness.
 #
-$LOAD_LATEX_COLOR = "\\usepackage[dvips]{color}";
-$LATEX_COLOR = "\\pagecolor[gray]{.7}";
+#$LOAD_LATEX_COLOR = "\\usepackage{xcolor}";
+#$LATEX_COLOR = "C0C0C0";
 
 
 # -white
@@ -48,7 +60,7 @@ $WHITE_BACKGROUND = 0;
 # This specifies the type of images produced by latex2html when processing
 # unknown environments and/or e.g. math formulae.
 #
-@IMAGE_TYPES = qw(png gif);
+@IMAGE_TYPES = qw(svg png gif);
 $IMAGE_TYPE  = $IMAGE_TYPES[0];
 
 
@@ -74,29 +86,24 @@ $HTML_VALIDATOR = '';
 $HTML_VALIDATE = 0;
 
 
-##########  ICONSERVER  --- !! IMPORTANT !! ############################
+##########  ICONSERVER   ############################
 #
 # LaTeX2HTML uses many small graphics as icons within the navigation
 # panels, and for other purposes.
-# You *must* specify where these graphics are to be found, for use within
-# your documents.
+# You can specify a single location where these graphics are to be found,
+# to avoid creating a separate copy as part of each document.
 #
 # IMPORTANT: This location must not only be accessible to you, but also
 #            to the people who are to read your HTML documents.
 #
-# One option is to always use the  -local_icons switch (see below)
-# to have a copy of the icons together with your HTML document.
+# If $ICONSERVER is not set, latex2html will create
+# a copy of the icons together with your HTML document.
 # (This is safe, but wasteful if you have a large number of documents.)
 #
 # A better option is to set  $ICONSERVER  to point to a location that
 # is known to always (at least in principle) be available publicly.
 #
-# The default value for  $ICONSERVER  given below is within the local 
-# $LATEX2HTMLDIR. If this is *not* to be publicly available then you 
-#  **should change the value of $ICONSERVER to a site that is**.
-#
-# You probably have to talk to your Webmaster to provide access to the
-# icon directory. Some hints:
+# Some hints:
 # a) It's ok to set $ICONSERVER just to "/path/to/icons.$IMAGE_TYPE" (without
 #    the internet address) if /path/to is valid for your file system, *and*
 #    if www_root/path/to points to the same directory. Normally the www area
@@ -111,7 +118,7 @@ $HTML_VALIDATE = 0;
 #    In this case, customize &img_tag to use a central directory, say,
 #    "../icons".
 #
-$ICONSERVER = ''||'file:/usr/lib/latex2html/icons';
+$ICONSERVER = '';
 $ALTERNATIVE_ICONS = 0;
 
 
@@ -559,7 +566,7 @@ $DEBUG = 0;
 # -html_version
 # The default HTML version to be produced
 #
-$HTML_VERSION = '4.0';
+$HTML_VERSION = '5';
 
 
 # -no_math
@@ -590,13 +597,6 @@ $NETSCAPE_HTML = 0;
 $INTERLACE = 1;
 
 
-# Set this to 1 if you like the old LaTeX2HTML style to have a
-# border around the navigation links.
-# Values > 1 are also possible.
-#
-$NAV_BORDER = 0;
-  
-
 ### Colors ###
 #
 # If this is set you may set colors in your document (see the LaTeX
@@ -634,7 +634,7 @@ $DONT_INCLUDE = "2up:psfig:epsf:texinfo:pictex:" .
     "alltt:amstex:anysize:array:article:bm:book:bookman:" .
     "boxedminipage:cite:comment:courier:dcolumn:doc:eepic:" .
     "enumerate:epic:fleqn:float:floatflt:fullpage:index:" .
-    "inputenc:isolatin1:leqno:letter:llncs:makeidx:" .
+    "inputenc:luainputenc:isolatin1:leqno:letter:llncs:makeidx:" .
     "multicol:psfig:report:shadow:shapepar:showidx:" .
     "slides:syntonly:sz:tabls:times:twoside:umlaut:umlaute";
 
@@ -700,6 +700,7 @@ $DVIPS_MODE = '';
 #   the metafont mode (e.g. `toshiba').
 #
 $METAFONT_DPI = 0;
+$DVIPNG_DPI = 240;	# for best appearance
 
 
 # Controls which markup shows up between page and its foot.
@@ -745,7 +746,7 @@ $WORDS_IN_NAVIGATION_PANEL_TITLES = 4;
 # Effective values are those greater than 0.
 # Sensible values are between 0.1 - 4.
 #
-$MATH_SCALE_FACTOR = 1.6;
+$MATH_SCALE_FACTOR = 1;
 
 
 # This number, when defined, determines extra scaling for displayed equations.
@@ -761,7 +762,7 @@ $MATH_SCALE_FACTOR = 1.6;
 # Effective values are those greater than 0.
 # Sensible values are between 0.1 - 4.
 #
-$FIGURE_SCALE_FACTOR = 1.6;
+$FIGURE_SCALE_FACTOR = 1;
 
 
 # This is yet another scaling factor which has a special use.
@@ -773,7 +774,7 @@ $FIGURE_SCALE_FACTOR = 1.6;
 # This allows for better quality when the HTML page is printed.
 #  {figure}  environments are *not* affected by this factor.
 #
-#$EXTRA_IMAGE_SCALE = 2;
+#$EXTRA_IMAGE_SCALE = 2;	# set to 1 if $DVIPNG_DPI = 600
 
 
 # If this is set to 0 then any inlined images generated from "figure" 
@@ -811,6 +812,7 @@ $PNMFLIP = '/usr/bin/pnmflip';
 $PNMPAD = '/usr/bin/pnmpad';
 $PNMROTATE = '/usr/bin/pnmrotate';
 $PNMSCALE = '/usr/bin/pnmscale';
+$PNMCROP = '/usr/bin/pnmcrop';
 
 $GIFTOPNM = '/usr/bin/giftopnm';
 $JPEGTOPNM = '/usr/bin/jpegtopnm';
@@ -824,7 +826,6 @@ $TIFFTOPNM = '/usr/bin/tifftopnm';
 $ANYTOPNM = '/usr/bin/anytopnm';
 $BMPTOPPM = '/usr/bin/bmptoppm';
 $PCXTOPPM = '/usr/bin/pcxtoppm';
-$PICTTOPPM = '';
 $SGITOPNM = '/usr/bin/sgitopnm';
 $XBMTOPBM = '/usr/bin/xbmtopbm';
 $XWDTOPNM = '/usr/bin/xwdtopnm';
@@ -1066,8 +1067,8 @@ sub meta_information {
 ### Icons ################################################################
 
 # Icon names and real icon files. 
-
-foreach $typ (@IMAGE_TYPES) {
+# gif icons are also availble.  no svg icons available.
+foreach $typ ('png') {
     %{"icons_$typ"} = (
 	'cross_ref_visible_mark' ,"crossref.$typ",
 	'anchor_mark' , '', # ,'&#160;',
@@ -1094,7 +1095,7 @@ foreach $typ (@IMAGE_TYPES) {
     )
 };
 if (!%icons) {
-    %icons = %{"icons_$IMAGE_TYPE"};
+    %icons = %{"icons_png"};
 }
 
 if (!%iconsizes) {
@@ -1127,7 +1128,6 @@ sub img_tag {
     local($iconmark) = @_;
     local($icon) = $icons{$iconmark};
     local($alt);
-    local($align) = " ALIGN=\"BOTTOM\" ";
 
     $alt = join ('|', "up", "next_group", "next_inactive", "previous_group"
 		, "next", "previous", "change_begin_right", "change_begin"
@@ -1136,27 +1136,24 @@ sub img_tag {
 
     if ($icon =~ /(gif|png)$/) {
 	$used_icons{$icon} = 1;
-	if ($iconmark =~ /change_(begin|end|delete)_right/) { $align = ' ' };
 	local($pre);
-	local($nav_border) = "\"$NAV_BORDER\"";
 	if ($iconmark =~ /($alt)/) {
 	    $pre = "\n";
 	    $alt = $1;
 	}
 	else {
 	    $pre = "";
-	    $nav_border = '"1"';
 	    $alt = '[*]';
 	 };
 
 	if ($LOCAL_ICONS) {
-	    return join('', $pre ,'<IMG ', $iconsizes{$alt} || '', $align
-			,'BORDER=', $nav_border, ' ALT="', $alt
+	    return join('', $pre ,'<IMG ', $iconsizes{$alt} || ''
+			,' ALT="', $alt
 			,'" SRC="', $icon, '">' );
 	}
 	else {
-	    return join('', $pre ,'<IMG ', $iconsizes{$alt} || '', $align
-			,'BORDER=', $nav_border, ' ALT="', $alt, "\"\n"
+	    return join('', $pre ,'<IMG ', $iconsizes{$alt} || ''
+			,' ALT="', $alt, "\"\n"
 			,' SRC="', $ICONSERVER, "/$icon", '">' );
 	}
     }
