@@ -1,36 +1,37 @@
 # -*- perl -*-
 #
-### File: html4.01.pl
-### Language definitions for HTML 4.01
+### File: html5.pl
+### Language definitions for HTML 5
 
 
-$DOCTYPE = "-//W3C//DTD HTML 4.01";
-$DTD_URL = "http://www.w3.org/TR/html4/strict.dtd";
+$DOCTYPE = "HTML";
+$DTDcomment = "<!DOCTYPE HTML>\n";
 
 $USING_STYLES = 1;
-$math_class = ' ALIGN="CENTER" CLASS="mathdisplay"';
+$math_class = ' CLASS="displaymath"';
 $eqno_class = ' CLASS="eqno"';
 
 # Note that htmlx.x.pl prior modules are *NOT*already loaded.
 
-$declarations{'tiny'} = '<SMALL CLASS="TINY"></SMALL>';
-$declarations{'Tiny'} = '<SMALL CLASS="XTINY"></SMALL>';
-$declarations{'scriptsize'} = '<SMALL CLASS="SCRIPTSIZE"></SMALL>';
-$declarations{'small'} = '<SMALL CLASS="SMALL"></SMALL>';
-$declarations{'Small'} = '<SMALL CLASS="FOOTNOTESIZE"></SMALL>';
-$declarations{'SMALL'} = '<SMALL CLASS="SCRIPTSIZE"></SMALL>';
-$declarations{'footnotesize'} = '<SMALL CLASS="FOOTNOTESIZE"></SMALL>';
-$declarations{'large'} = '<BIG CLASS="LARGE"></BIG>';
-$declarations{'Large'} = '<BIG CLASS="XLARGE"></BIG>';
-$declarations{'LARGE'} = '<BIG CLASS="XXLARGE"></BIG>';
-$declarations{'huge'} = '<BIG CLASS="HUGE"></BIG>';
-$declarations{'Huge'} = '<BIG CLASS="XHUGE"></BIG>';
+$declarations{'tiny'} = '<SPAN CLASS="TINY"></SPAN>';
+$declarations{'Tiny'} = '<SPAN CLASS="XTINY"></SPAN>';
+$declarations{'scriptsize'} = '<SPAN CLASS="SCRIPTSIZE"></SPAN>';
+$declarations{'small'} = '<SPAN CLASS="SPAN"></SPAN>';
+$declarations{'Small'} = '<SPAN CLASS="FOOTNOTESIZE"></SPAN>';
+$declarations{'SMALL'} = '<SPAN CLASS="SCRIPTSIZE"></SPAN>';
+$declarations{'footnotesize'} = '<SPAN CLASS="FOOTNOTESIZE"></SPAN>';
+$declarations{'large'} = '<SPAN CLASS="LARGE"></SPAN>';
+$declarations{'Large'} = '<SPAN CLASS="XLARGE"></SPAN>';
+$declarations{'LARGE'} = '<SPAN CLASS="XXLARGE"></SPAN>';
+$declarations{'huge'} = '<SPAN CLASS="HUGE"></SPAN>';
+$declarations{'Huge'} = '<SPAN CLASS="XHUGE"></SPAN>';
 
 $declarations{'sl'} = '<I CLASS="slanted"></I>';
 $declarations{'slshape'} = '<I CLASS="slanted"></I>';
-$declarations{'sf'} = '<I CLASS="sans"></I>';
-$declarations{'sffamily'} = '<I CLASS="sans"></I>';
-$declarations{'scshape'} = '<I CLASS="smcaps"></I>';
+$declarations{'sf'} = '<SPAN style="font-family:sans-serif"></SPAN>';
+$declarations{'sffamily'} = '<SPAN style="font-family:sans-serif"></SPAN>';
+$declarations{'scshape'} = '<SPAN style="font-variant:small-caps"></SPAN>';
+$declarations{'tt'} = '<SPAN style="font-family:monospace"></SPAN>';
 
 ### Allow for alignment to work
 
@@ -41,16 +42,6 @@ sub do_env_flushleft { &declared_env('flushleft', @_) }
 sub do_env_raggedright { &declared_env('flushleft', @_) }
 sub do_env_raggedleft { &declared_env('flushright', @_) }
 
-sub do_cmd_centering { 
-    # MRO *opentags has no effect
-    local($_)= @_; &declared_env('center', $_) }
-sub do_cmd_raggedright {
-    # MRO *opentags has no effect
-    local($_) = @_; &declared_env('flushleft', $_) }
-sub do_cmd_raggedleftt {
-    # MRO *opentags has no effect
-    local($_) = @_; &declared_env('flushright', $_) }
-
 sub do_cmd_underline {
     &styled_text_chunk('U','','text','decoration','underline','',@_)}
 
@@ -77,10 +68,7 @@ $percent_type = "\^\\d+(%|\\%|$percent_mark)?\$";
 $coord_type = "\^\\s*(\$|\\d+(\\s*,\\s*\\d+)+\\s*\$)";  # comma-separated list of numbers
 $pixel_type = "\^\\d+\$";
 $length_type = "\^\\d+\%?\$";
-$param_type = "\&\#[\\dA-Za-z]+\;";
-$mime_type = "^\\s*\\w+\/\\w+\\s*\$";
-$mime_type_list = "^\\s*(?:\\w+\/\\w+,\\s*)*\\w+\/\\w+\\s*\$";
-$name_type = "\^[A-Za-z][A-Za-z_\\d\\-\\.:]*\$";
+$name_type = "\^[A-Za-z]([A-Za-z\\d\\-\\.]*\$";
 $string_type = $URL_type = $script_type = $ISOdate_type = $Internet_type =
 	$CDATA_type = "\^.*\$";
 $id_list_type = "\^\\s*\$name_type(\\s+$name_type)*\\s*\$";
@@ -100,7 +88,6 @@ $numstyle_type = "1,a,A,i,I,";
 $boolean_type = "0,1";
 $frame_type = ",void,above,below,hsides,lhs,rhs,vsides,box,border,";
 $rules_type = ",none,groups,rows,cols,all,";
-$scope_type = ",row,col,rowgroup,colgroup,";
 
 $color_names_list = "Black|Silver|Gray|White|Maroon|Red|Purple|Fuchsia|"
         . "Green|Lime|Olive|Yellow|Navy|Blue|Teal|Aqua";
@@ -110,7 +97,6 @@ $color_type = "\^($color_names_list|\\\\?\#?\\w{6})\$";
 
 %closed_tags_list = (
 	  'A' , '' 
-	, 'ABBR' , ''
 	, 'ACRONYM' , ''
 	, 'ADDRESS' , ''
 	, 'APPLET' , '(CODE|OBJECT),HEIGHT,WIDTH'
@@ -153,7 +139,6 @@ $color_type = "\^($color_names_list|\\\\?\#?\\w{6})\$";
   	, 'NOSCRIPT' , ''
   	, 'OBJECT' , ''
   	, 'OL' , ''
-  	, 'OPTGROUP' , 'LABEL'
   	, 'OPTION' , ''
    	, 'P' , ''
   	, 'PRE' , ''
@@ -206,29 +191,22 @@ $__ID_rx = $__LANG_rx = $name_type_rx;
 $__DIR_rx_list = $dir_type;
 $__CLASS_rx = $__STYLE_rx = $__TITLE_rx = $cdata_type_rx;
 
-$__ONCLICK_rx = $__ONDBLCLICK_rx = 
-    $__ONMOUSEUP_rx = $__ONMOUSEDOWN_rx = $__ONMOUSEOVER_rx = $__ONMOUSEMOVE_rx =
-    $__ONMOUSEOUT_rx = $__ONKEYPRESS_rx = $__ONKEYDOWN_rx = $__ONKEYUP_rx = $script_type;
+$__ONCLICK_rx = $__ONDBLCLICK_rx = $__ONMOUSEUP_rx = $__ONMOUSEDOWN_rx = $__ONMOUSEOVER_rx = $__ONMOUSEMOVE_rx =
+	$__ONMOUSEOUT_rx = $__ONKEYPRESS_rx = $__ONKEYDOWN_rx = $__ONKEYUP_rx = $script_type;
 
 
 
 $A_attribs = ",SHAPE,DIR,";
 $A__SHAPE = $shape_type;
 $A__DIR = $dir_type;
-$A_attribs_rx_list = join('',",HREF,HREFLANG,NAME,TYPE,REL,REV,CHARSET,TARGET,ACCESSKEY,COORDS,TABINDEX,ONFOCUS,ONBLUR",$style_attribs);
+$A_attribs_rx_list = join('',",HREF,NAME,REL,REV,CHARSET,TARGET,ACCESSKEY,COORDS,TABINDEX,ONFOCUS,ONBLUR",$style_attribs);
 $A__HREF_rx = $URL_type;
-$A__HREFLANG_rx = $name_type;
-$A__NAME_rx = $A__REL_rx = $A__REV_rx = $string_type; 
-$A__TYPE_rx = $mime_type;
+$A__NAME_rx = $A__REL_rx = $A__REV_rx = $string_type;
 $A__CHARSET_rx = $A__TARGET_rx = $A__ACCESSKEY_rx = $CDATA_type;
 $A__COORDS_rx = $coord_type;
 $A__TABINDEX_rx = $num_type;
 $A__ONFOCUS_rx = $A__ONBLUR_rx = $script_type;
 
-$ABBR_attribs = ",DIR,";
-$ABBR__DIR = $dir_type;
-$ABBR_attribs_rx_list =  $style_attribs;
-
 $ACRONYM_attribs = ",DIR,";
 $ACRONYM__DIR = $dir_type;
 $ACRONYM_attribs_rx_list =  $style_attribs;
@@ -376,12 +354,11 @@ $FONT__FACE_rx = $CDATA_type;
 $FORM_attribs = ",METHOD,ENCTYPE,DIR,";
 $FORM__METHOD = ",get,post,";
 $FORM__DIR = $dir_type;
-$FORM__ENCTYPE = ",text\/plain,application\/x\-www\-form\-urlencoded,multipart\/form\-data,";
-$FORM_attribs_rx_list = join('',",ACTION,TARGET,ACCEPT,ACCEPT-CHARSET,ONSUBMIT,ONRESET",$style_attribs);
+$FORM__ENCTYPE = ",text\/plain,application\/x\-www\-form\-urlencoded,";
+$FORM_attribs_rx_list = join('',",ACTION,TARGET,ACCEPT-CHARSET,ONSUBMIT,ONRESET",$style_attribs);
 $FORM__ACTION_rx = $URL_type;               # required
 $FORM__TARGET_rx = ${FORM__ACCEPT-CHARSET_rx} = $CDATA_type;
 $FORM__ONSUBMIT_rx = $FORM__ONRESET_rx = $script_type;
-$FORM__ACCEPT_rx = $mime_type_list;
 
 $FRAME_attribs = ",FRAMEBORDER,NORESIZE,SCROLLING,";
 $FRAME__FRAMEBORDER = $boolean_type;
@@ -441,15 +418,14 @@ $IFRAME__MARGINWIDTH_rx = $FRAME__MARGINHEIGHT_rx = $pixel_type;
 $IMG_attribs = ",ALIGN,ISMAP,DIR,";
 $IMG__ALIGN =  $Ialign_type;
 $IMG__DIR = $dir_type;
-$IMG_attribs_rx_list = join('',",NAME,WIDTH,HEIGHT,BORDER,HSPACE,VSPACE,SRC,USEMAP,ALT,LONGDESC",$style_attribs);
+$IMG_attribs_rx_list = join('',",WIDTH,HEIGHT,BORDER,HSPACE,VSPACE,SRC,USEMAP,ALT,LONGDESC",$style_attribs);
 $IMG__WIDTH_rx = $IMG__HEIGHT_rx = $IMG__BORDER_rx = $IMG__HSPACE_rx = $IMG__VSPACE_rx = $pixel_type;
 $IMG__SRC_rx = $URL_type;      # required
 $IMG__USEMAP_rx = $IMG__LONGDESC_rx = $URL_type;
 $IMG__ALT_rx = $string_type;
-$IMG__NAME_rx = $name_type;
 
 
-$INPUT_attribs = ",TYPE,ISMAP,CHECKED,DISABLED,READONLY,ALIGN,DIR,";
+$INPUT_attribs = ",TYPE,CHECKED,DISABLED,READONLY,ALIGN,DIR,";
 $INPUT__TYPE = ",text,password,checkbox,radio,submit,reset,file,hidden,image,button";
 $INPUT__ALIGN = $Ialign_type;
 $INPUT__DIR = $dir_type;
@@ -457,10 +433,9 @@ $INPUT_attribs_rx_list = join('',",SIZE,MAXLENGTH,NAME,VALUE,SRC,ALT,USEMAP,TABI
 	,"ONFOCUS,ONBLUR,ONSELECT,ONCHANGE",$style_attribs);
 $INPUT__TABINDEX_rx = $INPUT__MAXLENGTH_rx = $num_type;
 $INPUT__SIZE_rx = $INPUT__ACCESSKEY_rx = $INPUT__NAME_rx = $INPUT__VALUE_rx = 
-        $INPUT__ALT_rx = $CDATA_type;
+ $INPUT__ACCEPT_rx = $INPUT__ALT_rx = $CDATA_type;
 $INPUT__SRC_rx = $INPUT__USEMAP_rx = $URL_type;
 $INPUT__ONFOCUS_rx = $INPUT__ONBLUR_rx = $INPUT__ONSELECT_rx = $INPUT__ONCHANGE_rx = $script_type;
-$INPUT__ACCEPT_rx = $mime_type_list;
 
 $ISINDEX_attribs = ",DIR,";
 $ISINDEX__DIR = $dir_type;
@@ -511,14 +486,9 @@ $OBJECT__NAME_rx = $CDATA_type;
 $OBJECT__WIDTH_rx = $OBJECT__HEIGHT_rx = $length_type;
 $OBJECT__TABINDEX_rx = $num_type;
 
-$OPTGROUP_attribs = ",DISABLED,";
-$OPTGROUP_attribs_rx_list = ",LABEL,";
-$OPTGROUP__LABEL_rx = $name_type;
-
-$OPTION_attribs = ",SELECTED,DISABLED,";
-$OPTION_attribs_rx_list = ",LABEL,VALUE,";
-$OPTION__LABEL_rx = $name_type;
-$OPTION__VALUE_rx = $CDATA_type;
+$OPTION_attribs = ",SELECTED,";
+$OPTION_attribs_rx_list = ",VALUE,";
+$OPTION__VALUE = $string_type;
 
 $PARAM_attribs_rx_list = ",NAME,VALUE,";
 $PARAM__NAME_rx = $string_type;   # required
@@ -602,15 +572,13 @@ $TD__ALIGN = $TH__ALIGN = $TR__ALIGN = $calign_type;
 $TD__VALIGN = $TH__VALIGN = $TR__VALIGN = $valign_type;
 $TD__DIR = $TH__DIR = $TR__DIR = $dir_type;
 $TD_attribs_rx_list = $TH_attribs_rx_list = join('',
-     ",COLSPAN,ROWSPAN,WIDTH,HEIGHT,CHAR,CHAROFF,BGCOLOR,ABBR,AXIS,HEADERS,SCOPE,"
-    , $style_attribs);
+		",COLSPAN,ROWSPAN,WIDTH,HEIGHT,CHAR,CHAROFF,BGCOLOR,ABBR,AXIS,AXES",$style_attribs);
 $TD__COLSPAN_rx = $TD__ROWSPAN_rx = $TD__WIDTH_rx = $TD__HEIGHT_rx = $TD__CHAROFF_rx = $num_type;
 $TH__COLSPAN_rx = $TH__ROWSPAN_rx = $TH__WIDTH_rx = $TH__HEIGHT_rx = $TH__CHAROFF_rx = $num_type;
 $TD__CHAR_rx = $TH__CHAR_rx = $cdata_type;
 $TD__BGCOLOR_rx = $TH__BGCOLOR_rx = $color_type;
 $TD__ABBR_rx = $TH__ABBR_rx  = $TD__AXIS_rx = $TH__AXIS_rx = $cdata_type;
-$TD__SCOPE_rx = $TH__SCOPE_rx = $scope_type;
-$TD__HEADERS_rx = $TH__HEADERS_rx = $id_list_type;
+$TD__AXES_rx = $TH__AXES_rx = $id_list_type;
 
 
 $TEXTAREA_attribs = ",DISABLED,READONLY,DIR,";
@@ -676,7 +644,7 @@ $wrap_parbox_rx = "(\\\\begin$O\\d+${C}tex2html_deferred$O\\d+$C)?"
 
 sub translate_colspec {
     local($colspec,$celltag) = @_;
-    local($cellopen) = "<$celltag ALIGN";
+    local($cellopen) = "<$celltag CLASS";
     local($cellclose) = "</$celltag>\n";
     local($len,$pts,@colspec,$char,$cols,$repeat,$celldata,$at_text,$after_text);
     local($frames, $rules, $prefix,$border)=('','','','');
@@ -713,13 +681,6 @@ sub translate_colspec {
 	    $at_text = $after_text = '';
 	    $cols++;
 
-	} elsif ( $char =~ /^(l|X)$/ ) {
-	    if ($at_text) { $at_text = $art_br.$at_text; $after_text = $art_br; }
-	    push(@colspec
-	        ,"$cellopen=\"LEFT\"$NOWRAP>$at_text$content_mark$after_text$cellclose");
-	    $at_text = $after_text = '';
-	    $cols++;
-
 	} elsif ( $char eq "r" ) {
 	    if ($at_text) { $at_text = $art_br.$at_text; $after_text = $art_br; }
 	    push(@colspec
@@ -730,7 +691,6 @@ sub translate_colspec {
 	} elsif ( $char =~ /^(p|m|b|t)$/ ) {
 	    local($valign);
 	    $valign = (($char eq "b")? "BOTTOM" : (($char eq "m")? "MIDDLE" : "TOP"));
-	    $valign = " VALIGN=\"${valign}\"";
 	    $colspec =~ s/^\s*\{([^\}]*)\}\s*/$celldata=$1;''/e;
 
 	    local($pxs,$len) = &convert_length($celldata) if ($celldata);
@@ -741,7 +701,7 @@ sub translate_colspec {
 	    }
 	    if ($at_text) { $at_text = $art_br.$at_text; $after_text = $art_br; }
 	    push(@colspec
-		,"$cellopen=\"LEFT\"${valign}$celldata>$at_text$content_mark$after_text$cellclose");
+		,"$cellopen=\"LEFT ${valign}\" $celldata>$at_text$content_mark$after_text$cellclose");
 	    $at_text = $after_text = '';
 	    $cols++;
 
@@ -868,6 +828,14 @@ sub translate_colspec {
 		$repeat--;
 	    };
 	    $colspec = $celldata . $colspec;
+	} elsif ( $char =~ /^(l|X)$/ ||
+		  $char =~ /^.$/ ) {	# also the fallback for unknown column types
+	    if ($at_text) { $at_text = $art_br.$at_text; $after_text = $art_br; }
+	    push(@colspec
+	        ,"$cellopen=\"LEFT\"$NOWRAP>$at_text$content_mark$after_text$cellclose");
+	    $at_text = $after_text = '';
+	    $cols++;
+
 	};
     };
     $colspec[$#colspec] =~ s/($art_br)?$cellclose/$at_text$1$cellclose/
@@ -952,10 +920,10 @@ sub process_tabular {
     local($i,@colspec,$char,$cols,$cell,$htmlcolspec,$frames,$rules);
     local(@rows,@cols,$border,$frame);
     local($colspan,$cellcount);
-    
+
     # set a flag to indicate whether there are any \multirow cells
     my $has_multirow = 1 if (/\\multirow/s);
-    
+
     # convert \\s inside \parbox commands to \newline s;
     # catch nestings
 
@@ -976,7 +944,7 @@ sub process_tabular {
 
     if ($color_env) {
 	local($color_test) = join(',',@$open_tags_R);
-	if ($color_test =~ /(color{[^}]*})/g ) {
+	if ($color_test =~ /(color\{[^}]*\})/g ) {
 	    $color_env = $1;
 	}
     }
@@ -1024,7 +992,7 @@ sub process_tabular {
     $rules  .= "r" if ( s/\\[hv]line//g );
     #RRM:  retain any \cline to gobble its argument
 
-    if ( $frames || $rules ) { $border = " BORDER=\"1\""; };
+    if ( $frames || $rules ) { $border = " BORDER"; };
 
     # convert \\s inside \parbox commands to \newline s;
     # catch nestings
@@ -1036,7 +1004,7 @@ sub process_tabular {
     if ($tab_width) {
 	if ($tab_width =~ /(\%|$percent_mark)/) { $tab_width = "\"$tab_width\"" }
 	elsif ($tab_width <= 1) {$tab_width = "\"".(100 x $tab_width)."\"" }
-	$tab_width = " WIDTH=$tab_width";
+	$tab_width = " WIDTH:$tab_width;";
     } else { $tab_width = '' }
 
 #    if ($TABLE_CAPTIONS) { # captions for super-tabular environment
@@ -1050,19 +1018,15 @@ sub process_tabular {
 
     if ($table_captions) {
 	$return = join('', (($cap_anchors)? "$cap_anchors\n" : '')
-		, "<TABLE$env_id$lang CELLPADDING=3"
-		, $border
-		, ($halign ? " ALIGN=\"$halign\"" : '')
-		, $tab_width, ">");
+		, "<TABLE$env_id$lang class=\"PAD $border\" style=\""
+		, $tab_width, "\">");
 	$return .= $table_captions;
 #	$return .= "\n<CAPTION$lang>$captions</CAPTION>";
 #	$captions = '';
 #	$cap_anchors = '';
     } else { 
-	$return = join('', "<TABLE$env_id$lang CELLPADDING=3"
-		, $border
-		, ($halign ? " ALIGN=\"$halign\"" : '')
-		, $tab_width, ">");
+	$return = join('', "<TABLE$env_id$lang class=\"PAD $border\" style=\""
+		, $tab_width, "\">");
     }
     $env_id = '';
 
@@ -1101,12 +1065,12 @@ sub process_tabular {
 	$return .= "\n<TR$valign>";
 	@cols = split(/$html_specials{'&'}/o);
 
-	if ($has_multirow) {
+	if ($has_multirow) { 
 	    # decrement the counters for multi-row cells 
 	    my @trow_spec = map {$_>0? --$_ : 0 } @row_spec;
 	    @row_spec = @trow_spec;
 	}
-
+ 
 	for ( $i = 0; $i <= $#colspec; $i++ ) {
 	    # skip this cell if it is covered by a \multirow
 	    next if ($has_multirow && @row_spec[$i] > 0);
@@ -1266,43 +1230,6 @@ sub do_cmd_multicolumn {
     $text = &translate_commands($text) if ($text =~ /\\/);
     $text;
 }
-sub do_cmd_multirow {
-    local($_) = @_;
-    local($dmy1,$dmy2,$dmy3,$dmy4,$spanrows,$pxs,$rwidth,$valign,$vspec,$text);
-    $spanrows = &missing_braces unless (
-	(s/$next_pair_pr_rx/$spanrows=$2;''/eo)
-        ||(s/$next_pair_rx/$spanrows=$2;''/eo));
-    my $rowspan = 0+$spanrows;
-    # set the counter for this column to the number of rows covered
-    @row_spec[$i] = $rowspan;
-
-    $colspec =~ /^<([A-Z]+)/;
-    local($celltag) = $1;
-
-    # read the width, but ignore it
-    $rwidth = &missing_braces unless (
-	(s/$next_pair_pr_rx/$rwidth=$2;''/eo)
-	||(s/$next_pair_rx/$rwidth=$2;''/eo));
-
-    # catch cases where the \textwidth has been discarded
-    $rwidth =~s!^(\w)($OP\d+$CP)\s*(\d|\d*\.\d+)\2$!$1\{$3\\textwidth\}!;
-
-    ($pxs,$rwidth) = &convert_length($rwidth);
-
-    $valign = &missing_braces unless (
-        (s/$next_pair_pr_rx/$valign=$2;''/eo)
-        ||(s/$next_pair_rx/$valign=$2;''/eo));
-    $vspec = ' VALIGN="TOP"' if $valign;
-    if ($valign =~ /m/i) { $vspec =~ s/TOP/MIDDLE/ }
-    elsif ($valign =~ /b/i) { $vspec =~ s/TOP/BOTTOM/ }
-
-    $colspec =~ s/VALIGN="\w+"// if $vspec; # avoid duplicate tags
-    $colspec =~ s/>$content_mark/$vspec ROWSPAN=$rowspan WIDTH=$pxs$&/;
-
-    $text = &styled_text_chunk('SPAN','mrow','','','','', $_);
-    $text = &translate_commands($text) if ($text =~ /\\/);
-    $text;
-}
 
 ## Mathematics environments
 
@@ -1412,9 +1339,12 @@ sub do_env_tex2html_wrap_inline {
     } else { $_ }
 }
 
-# Allocate a fixed width for the equation-numbers:
-#$seqno = "\n<TD WIDTH=1 ALIGN=\"CENTER\">\n";
 
+
+# produces a <DIV class="equation">
+# containing three words:  &nbsp; <IMG> (eqno)
+# use with css: DIV.equation { text-align-last:justify; white-space: nowrap; }
+# to place <IMG> in center of line and (eqno) at right edge 
 sub do_env_equation {
     local($_) = @_;
     local($math_mode, $failed, $labels, $comment) = ("equation",'','');
@@ -1429,9 +1359,9 @@ sub do_env_equation {
     local($math_start,$math_end)= ($sbig,$ebig);
 
     local($eqno);
-    local($seqno) = join('',"\n<TD$eqno_class WIDTH=10 ALIGN=\""
-                         , (($EQN_TAGS =~ /L/)? 'LEFT': 'RIGHT')
-		         , "\">\n");
+    local($seqno) = join('',"\n"
+#                         , (($EQN_TAGS =~ /L/)? 'LEFT': 'RIGHT')
+		         , "\n");
     do { # get the equation number
 	$global{'eqn_number'}++;
 	$eqno = &translate_commands('\theequation');
@@ -1453,53 +1383,40 @@ sub do_env_equation {
 	$eqno = join('',$EQNO_START, $eqno, $EQNO_END)
     } else { $eqno = '&nbsp;' } # spacer, when no numbering
 
-    # include the equation-number, using a <TABLE>
-    local($halign) = " ALIGN=\"CENTER\"" unless $FLUSH_EQN;
+    # include the equation-number, using a <DIV class="equation">
+    local($halign) = " &nbsp; " unless $FLUSH_EQN;
     local($lang) = &get_current_language();
     if ($EQN_TAGS =~ /L/) {
 	# equation number on left
 	($math_start,$math_end) =
-	    ("\n<TABLE$env_id$lang WIDTH=\"100%\" ALIGN=\"CENTER\""
-		. (($border)? " BORDER=\"$border\"" : '')
-		. (($attribs)? " $attribs" : '')
-		. ">\n<TR VALIGN=\"MIDDLE\">". $seqno . $eqno
-		. "</TD>\n<TD$halign NOWRAP>$sbig"
-	    , "$ebig</TD>\n</TR></TABLE>");
+	    ($seqno . $eqno
+		. "$sbig $halign"
+	    , "$ebig\n");
 	$border = $attribs = $env_id = '';
     } else {
 	# equation number on right
 	($math_start,$math_end) =
-	    ("\n<TABLE$env_id$lang WIDTH=\"100%\" ALIGN=\"CENTER\""
-		. (($border)? " BORDER=\"$border\"" : '')
-		. (($attribs)? " $attribs" : '')
-		. ">\n<TR VALIGN=\"MIDDLE\"><TD></TD>"
-		. "<TD$halign NOWRAP>$sbig"
-	    , $ebig .'</TD>'. $seqno . $eqno ."</TD></TR>\n</TABLE>");
+	    ("$halign $sbig"
+	    , $ebig .' '. $seqno . $eqno ."\n");
 	$border = $attribs = $env_id = '';
     }
 
     ($labels, $comment, $_) = &process_math_env($math_mode,$_);
     if ($failed) {
-	$_ = join ('', $comment, $labels, $math_start
-	    , &process_undefined_environment('displaymath', $id, $saved)
-	    , $math_end );
+	$_ = join ('', $comment, $math_start
+		   , &process_math_in_latex("indisplay", '', '', $saved)
+		   , $math_end );
     } else {
 	s/^[ \t]*\n?/\n/; s/\n?[ \t]*$/\n/;
 	$_ = join('', $comment, $labels, $math_start, $_, $math_end );
     }
     if ($border||($attribs)) { 
-	join('',"<BR>\n<DIV$math_class>\n"
+	join('',"\n<DIV class=\"equation\">\n"
 	    , &make_table( $border, $attribs, '', '', '', $_ )
-	    , "\n<BR CLEAR=\"ALL\">");
-    } elsif ($failed) {
-	$falign = (($EQN_TAGS =~ /L/)? 'LEFT' : 'RIGHT') if ($eqno);
-	local($fclass) = $math_class;
-	$fclass =~ s/(ALIGN=\")[^"]*/$1$falign/;
-	join('',"<BR>\n<DIV$fclass>\n"
-	    , $_ , "\n<BR CLEAR=\"ALL\"></DIV><P></P>")
+	    , "\n");
     } else { 
-	join('', "<BR><P></P>\n<DIV$math_class>\n"
-	    , $_ ."\n</DIV><BR CLEAR=\"ALL\"><P></P>");
+	join('', "\n<DIV class=\"equation\">\n"
+	    , $_ ."</DIV>");
     }
 }
 
@@ -1517,7 +1434,7 @@ sub do_env_displaymath {
 	if (($DISP_SCALE_FACTOR)&&($DISP_SCALE_FACTOR >= 1.2 ));
     ($labels, $comment, $_) = &process_math_env($math_mode,$_);
     if ($failed) {
-	$_ = &process_undefined_environment("displaymath", $id, $saved);
+	$_ = &process_math_in_latex("indisplay",'','',$saved);
 	s/^[ \t]*\n?/\n/; s/\n?[ \t]*$/\n/; 
 	$_ = (($comment.$labels)? "$comment$labels\n":''). $_;
     } else {
@@ -1575,7 +1492,7 @@ sub do_env_eqnarray {
 	($sarray, $elcell, $srcell, $erow, $earray, $sempty) = ( 
 	    "\n<TABLE$env_id$lang CELLPADDING=\"0\" ALIGN=\"CENTER\""
 	    , "</TD>\n<TD ALIGN=\"CENTER\" NOWRAP>"
-	    , "</TD>\n<TD ALIGN=\"LEFT\" WIDTH=\"50%\" NOWRAP>"
+	    , "</TD>\n<TD ALIGN=\"LEFT\" NOWRAP>"
 	    , "</TD></TR>", "\n</TABLE>", "</TD>\n<TD>" );
 	$env_id = '';
 	$sarray .= (($no_eqn_numbers) ? ">" :  " WIDTH=\"100%\">" );
@@ -1585,10 +1502,10 @@ sub do_env_eqnarray {
 	if ($EQN_TAGS =~ /L/) { # number on left
 	    ($srow, $slcell, $ercell) = (
 		"\n<TR$valign>" . $seqno
-		, "</TD>\n<TD NOWRAP WIDTH=\"50%\" ALIGN=", '');
+		, "</TD>\n<TD NOWRAP ALIGN=", '');
 	} else { # equation number on right
 	    ($srow, $slcell, $ercell) = ("\n<TR$valign>"
-		, "<TD NOWRAP WIDTH=\"50%\" ALIGN="
+		, "<TD NOWRAP ALIGN="
 		, '</TD>'. $seqno );
 	}
 
